type Configuration = ButtonlessConfiguration | WithButtonConfiguration;
type uiSettingsWithButton = {
    recommendedPaymentMethod?: boolean;
    size?: 'small' | 'large';
    borderRadius?: number;
    merchantLogoUri?: string;
    lng?: string;
};
type WithButtonConfiguration = Partial<{
    hideButton?: false;
    uiSettings: uiSettingsWithButton;
}> & Partial<BaseCallbacks & {
    onPayButtonClicked: () => void;
}> & BaseConfiguration;
type ButtonlessConfiguration = {
    hideButton: true;
} & Partial<{
    uiSettings?: Partial<{
        merchantLogoUri: string;
        lng: string;
    }>;
}> & Partial<BaseCallbacks> & BaseConfiguration;
type BaseConfiguration = Partial<Environment> & Partial<TimeoutConfiguration> & Partial<HostedResultScreen>;
type HostedResultScreen = {
    hostedResultScreen: {
        returnUri: string;
    };
};
type Environment = {
    production: boolean;
};
type TimeoutConfiguration = {
    maxWaitForResult: number;
};
type Resource = {
    paymentId: string;
    resourceToken: string;
};
type Page = 'cancel' | 'providers' | 'consent' | 'waiting-bank' | 'qr-code' | 'qr-code-loader' | 'send-to-bank' | 'return-from-bank' | 'account-selection' | 'checkout' | 'learn-more';
type BaseCallbacks = {
    onDone: (info: {
        resultStatus: 'success' | 'failed' | 'pending';
    }) => void;
    onCancel: () => void;
    onError: (error?: Error) => void;
    onExpired: () => void;
    onNavigation: (page: Page) => void;
};
type InitWebSdkReturnWithButtonless = {
    start: (resource: Resource) => {
        cleanup: () => void;
    };
    cleanup: () => void;
    openLearnMoreModal?: undefined;
    mount?: undefined;
};
type InitWebSdkReturnWithButton = {
    cleanup: () => void;
    openLearnMoreModal: () => void;
    start: (resource: Resource) => void;
    mount: (node: HTMLElement) => {
        start: (resource: Resource) => void;
        cleanup: () => void;
    };
};

declare function initWebSdk(_options: WithButtonConfiguration): InitWebSdkReturnWithButton;
declare function initWebSdk(_options: ButtonlessConfiguration): InitWebSdkReturnWithButtonless;

export { Configuration, initWebSdk };
